#!/bin/sh

TESTDEVDIR=/tmp/testdev

svdir=`pwd`
test -d ${TESTDEVDIR} || mkdir ${TESTDEVDIR}
##test -d ${TESTDEVDIR} && cd ${TESTDEVDIR} && /dev/MAKEDEV mtd

test -d ${TESTDEVDIR} && cd ${TESTDEVDIR} && mknod mtd0 c 90 0 && mknod mtd1 c 90 2 && mknod mtd2 c 90 4 && mknod mtd3 c 90 6

cd ${svdir}
exit 0
