#define RUBY_VERSION "1.8.5"
#define RUBY_RELEASE_DATE "2006-08-25"
#define RUBY_VERSION_CODE 185
#define RUBY_RELEASE_CODE 20060825

#define RUBY_VERSION_MAJOR 1
#define RUBY_VERSION_MINOR 8
#define RUBY_VERSION_TEENY 5
#define RUBY_RELEASE_YEAR 2006
#define RUBY_RELEASE_MONTH 8
#define RUBY_RELEASE_DAY 25

RUBY_EXTERN const char ruby_version[];
RUBY_EXTERN const char ruby_release_date[];
RUBY_EXTERN const char ruby_platform[];
